@@ -1,4 +1,5 @@
 use crate::error::Error;
+use std::fmt;
 
 /// A parsed Nagios range built from a literal string.
 /// A Nagios range works similar to [std::ops::RangeInclusive]
@@ -255,6 +256,15 @@ impl NagiosRange {
     }
 }
 
+impl fmt::Display for NagiosRange {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self.check_type {
+            CheckType::Inside => write!(f, "@{}:{}", self.start, self.end),
+            CheckType::Outside => write!(f, "@{}:{}", self.start, self.end),
+        }
+    }
+}
+
 /// This enum indicates if [NagiosRange::check()] should
 /// check if a value lies inside or outside of the range.
 #[derive(Debug, PartialEq, Copy, Clone)]
